@@ -1,8 +1,9 @@
 use strict;
 use warnings;
+use v5.10.1;
 package Plack::App::DAIA::Test;
 {
-  $Plack::App::DAIA::Test::VERSION = '0.471';
+  $Plack::App::DAIA::Test::VERSION = '0.48';
 }
 #ABSTRACT: Test DAIA Servers
 
@@ -29,7 +30,7 @@ sub test_daia {
         my $expected = shift;
         my $res = $app->retrieve($id);
         if (!_if_daia_check( $res, $expected, $test_name )) {
-            $@ = "The thing isa DAIA::Response" unless $@;
+            $@ = "retrieve method returned a DAIA::Response" unless $@;
             __PACKAGE__->builder->ok(0, $@);
         }
     }
@@ -53,7 +54,7 @@ sub test_daia_psgi {
                 $@ =~ s/\s*$//sg;
             }
             if (!_if_daia_check( $res, $expected, $test_name )) {
-                $@ = "No valid The thing isa DAIA::Response" unless $@;
+                $@ = "application returned a DAIA::Response" unless $@;
                 __PACKAGE__->builder->ok(0, $@);
             }
         };
@@ -116,7 +117,7 @@ Plack::App::DAIA::Test - Test DAIA Servers
 
 =head1 VERSION
 
-version 0.471
+version 0.48
 
 =head1 SYNOPSIS
 
@@ -146,7 +147,7 @@ version 0.471
     test_daia_psgi
         sub {
             my $id = shift;
-            my $daia = DAIA::Response->new();
+            my $daia = DAIA::Response->new;
             ...
             return $daia;
         },
@@ -171,8 +172,9 @@ L<DAIA::Response> object on success (C<$_> is also set to this response).
 
 =head2 test_daia ( $app, $id1 => sub { }, $id2 => ...  )
 
-Calls a DAIA server C<$app>'s request method with one or more identifiers,
-each given a test function.
+Calls a DAIA server C<$app>'s retrieve method with one or more identifiers,
+each given a test function. This does not add warnings and the error option
+is ignored (use test_daia_psgi instead if needed).
 
 =head2 test_daia_psgi ( $app, $id => sub { }, $id => ...  )
 
